@@ -9,6 +9,9 @@ import argparse
 import sys
 from webdriver_manager.firefox import GeckoDriverManager
 from selenium.webdriver.firefox.service import Service as FirefoxService
+from selenium.webdriver.chrome.service import Service as ChromiumService
+from webdriver_manager.chrome import ChromeDriverManager
+from webdriver_manager.core.utils import ChromeType
 from prettytable import PrettyTable, ALL
 from typing import List
 from decimal import Decimal
@@ -51,6 +54,10 @@ args = parser.parse_args()
 
 options = FirefoxOptions()
 options.add_argument("--headless")
+
+chrome_options = webdriver.ChromeOptions()
+chrome_options.add_argument("--headless")
+chrome_options.add_argument("--disable-gpu")
 #browser = webdriver.Firefox(executable_path="/users/krv/driver/geckodriver", options=options)
 
 ###################################################################################################################
@@ -653,6 +660,8 @@ def trends_google_play(gl, hl):
         alphabet = "aábcčdďeéěfghciíjklmnňoópqrřsštťuúůvwxyýzž"
     elif hl == "el":
         alphabet = "αβγδεζηθικλμνξοπρσςτυφχψω"
+    elif hl == "it":
+        alphabet = "abcdefghilmnopqrstuvzùúòóìíèéà"
     else:
         print(hl + " - ця мова поки що не підтримується")
         sys.exit(0)
@@ -661,7 +670,11 @@ def trends_google_play(gl, hl):
 
     print(Fore.GREEN + "* * * Виконую аналіз трендів... * * *" + Fore.WHITE)
 
-    browser = webdriver.Firefox(service = FirefoxService(GeckoDriverManager().install()), options=options)
+    try:
+        browser = webdriver.Firefox(service = FirefoxService(GeckoDriverManager().install()), options=options)
+    except Exception as e:
+        print ("Використовую ядро Chromium!")
+        browser = webdriver.Chrome(service=ChromiumService(ChromeDriverManager(chrome_type=ChromeType.CHROMIUM).install()), options=chrome_options)
     browser.implicitly_wait(10)
     browser.maximize_window()
 
